@@ -10,7 +10,7 @@ async def get_player_by_name(name: str) -> MojangPlayer:
     async with aiohttp.ClientSession() as session:
         response = await session.get(f"{MOJANG_API}/users/profiles/minecraft/{name}")
         if response.status != 200:
-            raise NoPlayerFoundError
+            raise NoPlayerFoundError(name)
     return MojangPlayer(await response.json())
 
 
@@ -18,7 +18,7 @@ async def get_player_by_uuid(uuid: str) -> MojangPlayer:
     async with aiohttp.ClientSession() as session:
         response = await session.get(f"{MOJANG_SESSION_SERVER}/session/minecraft/profile/{uuid.replace('-', '')}")
         if response.status != 200:
-            raise NoPlayerFoundError
+            raise NoPlayerFoundError(uuid)
     return MojangPlayer(await response.json())
 
 
@@ -26,5 +26,5 @@ async def get_player_name_history(uuid: str) -> NameHistory:
     async with aiohttp.ClientSession() as session:
         response = await session.get(f"{MOJANG_API}/user/profiles/{uuid}/names")
         if response.status != 200:
-            raise NoPlayerFoundError
+            raise NoPlayerFoundError(uuid)
     return NameHistory(await response.json())
