@@ -1,5 +1,5 @@
 from .. import utils
-from .stats import KillsDeaths, FinalKillsDeaths, WinsLosses
+from .stats import KillsDeaths, FinalKillsDeaths, WinsLosses, Ratio
 
 
 class Bedwars:
@@ -39,6 +39,7 @@ class Bedwars:
 class Prestige:
     def __init__(self, star):
         self.star = star
+        self.next = star + 1
         self.star_index = star // 100
         self.name = utils.get_bedwars_prestige_name(self.star_index)
         self.color = utils.get_bedwars_prestige_color(self.star_index)
@@ -55,10 +56,8 @@ class BedsBrokenLost:
     def __init__(self, broken, lost):
         self.broken = broken
         self.lost = lost
-        self.ratio = utils.get_ratio(broken, lost)
+        self.ratio = Ratio(self.broken, self.lost)
 
-    def increase(self, *, amount: int = 0):
-        return utils.get_increase(self.broken, self.lost, amount=amount)
 
 # regular modes
 class Solo:
