@@ -141,6 +141,8 @@ def get_ratio_next(ratio):
 
 def get_increase(positive_stat, negative_stat, *, amount: int = 0):
     ratio = get_ratio(positive_stat, negative_stat)
+    if ratio == float("inf"):
+        return ratio
     if not bool(amount):
         amount = (math.trunc(ratio) + 1) - ratio
     needed = (ratio + amount) * negative_stat - positive_stat
@@ -230,3 +232,11 @@ def get_rank(rank, prefix_raw, monthly_package_rank, new_package_rank, package_r
 
 def get_rank_color(rank):
     return rank_colors[rank]
+
+
+def get_profile_display(name, rank):
+    # returns either "[rank] name" or "name" depending on whether the player has a rank
+    if bool(rank):
+        return f"[{rank} {name}]"
+    else:
+        return name
